@@ -23,5 +23,15 @@ from .test_dataloader import *
 from .test_datadumper import *
 from .test_dumpload import *
 
+# Run tests for the attr plugin only if it is loaded
+try:
+    import attr
+    attr_module = True
+except ImportError:
+    attr_module = False
+
+if attr_module:
+    from .test_attrload import *
+
 if __name__ == '__main__':
     unittest.main()
