@@ -21,7 +21,7 @@ from enum import Enum
 from typing import Dict, List, NamedTuple, Optional, Set, Tuple, Union
 import unittest
 
-from typedload import dataloader
+from typedload import dataloader, load
 
 
 class TestRealCase(unittest.TestCase):
@@ -77,6 +77,23 @@ class TestRealCase(unittest.TestCase):
         loader.load(c, BoardItem)
 
 
+class TestLegacy(unittest.TestCase):
+
+    def test_legacyload(self):
+        A = NamedTuple('A', [('a', int), ('b', str)])
+        assert load({'a': 101, 'b': 'ciao'}, A) == A(101, 'ciao')
+
+    def test_nestedlegacyload(self):
+        A = NamedTuple('A', [('a', int), ('b', str)])
+        B = NamedTuple('B', [('a', A), ('b', List[A])])
+
+        assert load({'a': {'a': 101, 'b': 'ciao'}, 'b': []}, B) == B(A(101, 'ciao'), [])
+        assert load(
+            {'a': {'a': 101, 'b': 'ciao'}, 'b': [{'a': 1, 'b': 'a'},{'a': 0, 'b': 'b'}]},
+            B
+        ) == B(A(101, 'ciao'), [A(1, 'a'),A(0, 'b')])
+
+
 class TestUnion(unittest.TestCase):
 
     def test_ComplicatedUnion(self):
@@ -303,3 +320,26 @@ class TestBasicTypes(unittest.TestCase):
             loader.load(False, int)
             loader.load('ciao', str)
             loader.load('1', float)
+
+
+class TestHandlers(unittest.TestCase):
+
+    def test_custom_handler(self):
+        class Q:
+            def __eq__(self, other):
+                return isinstance(other, Q)
+
+        loader = dataloader.Loader()
+        loader.handlers.append((
+            lambda t: t == Q,
+            lambda l, v, t: Q()
+        ))
+        assert loader.load('test', Q) == Q()
+
+    def test_broken_handler(self):
+        loader = dataloader.Loader()
+        loader.handlers.insert(0, (lambda t: 33 + t is None, lambda l, v, t: None))
+        with self.assertRaises(TypeError):
+            loader.load(1, int)
+        loader.raiseconditionerrors = False
+        assert loader.load(1, int) == 1
